Class: Google::Apis::ToolresultsV1beta3::AppStartTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppStartTime

Returns a new instance of AppStartTime.



339
340
341
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fully_drawn_timeGoogle::Apis::ToolresultsV1beta3::Duration

A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +- 10,000 years. Corresponds to the JSON property fullyDrawnTime



327
328
329
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 327

def fully_drawn_time
  @fully_drawn_time
end

#initial_display_timeGoogle::Apis::ToolresultsV1beta3::Duration

A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +- 10,000 years. Corresponds to the JSON property initialDisplayTime



337
338
339
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 337

def initial_display_time
  @initial_display_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



344
345
346
347
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 344

def update!(**args)
  @fully_drawn_time = args[:fully_drawn_time] if args.key?(:fully_drawn_time)
  @initial_display_time = args[:initial_display_time] if args.key?(:initial_display_time)
end