Class: Google::Apis::ToolresultsV1beta3::BlankScreen

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

A warning that Robo encountered a screen that was mostly blank; this may indicate a problem with the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BlankScreen

Returns a new instance of BlankScreen.



456
457
458
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#screen_idString

The screen id of the element Corresponds to the JSON property screenId

Returns:

  • (String)


454
455
456
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 454

def screen_id
  @screen_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



461
462
463
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 461

def update!(**args)
  @screen_id = args[:screen_id] if args.key?(:screen_id)
end