Class: Google::Apis::ToolresultsV1beta3::EncounteredNonAndroidUiWidgetScreen
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::EncounteredNonAndroidUiWidgetScreen
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Additional details about encountered screens with elements that are not Android UI widgets.
Instance Attribute Summary collapse
-
#distinct_screens ⇒ Fixnum
Number of encountered distinct screens with non Android UI widgets.
-
#screen_ids ⇒ Array<String>
Subset of screens which contain non Android UI widgets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncounteredNonAndroidUiWidgetScreen
constructor
A new instance of EncounteredNonAndroidUiWidgetScreen.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncounteredNonAndroidUiWidgetScreen
Returns a new instance of EncounteredNonAndroidUiWidgetScreen.
619 620 621 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#distinct_screens ⇒ Fixnum
Number of encountered distinct screens with non Android UI widgets.
Corresponds to the JSON property distinctScreens
612 613 614 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 612 def distinct_screens @distinct_screens end |
#screen_ids ⇒ Array<String>
Subset of screens which contain non Android UI widgets.
Corresponds to the JSON property screenIds
617 618 619 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 617 def screen_ids @screen_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
624 625 626 627 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 624 def update!(**args) @distinct_screens = args[:distinct_screens] if args.key?(:distinct_screens) @screen_ids = args[:screen_ids] if args.key?(:screen_ids) end |