Class: Google::Apis::ToolresultsV1beta3::Environment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

An Environment represents the set of test runs (Steps) from the parent Execution that are configured with the same set of dimensions (Model, Version, Locale, and Orientation). Multiple such runs occur particularly because of features like sharding (splitting up a test suite to run in parallel across devices) and reruns (running a test multiple times to check for different outcomes).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Environment

Returns a new instance of Environment.



720
721
722
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_timeGoogle::Apis::ToolresultsV1beta3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are " smeared" so that no leap second table is needed for interpretation, using a 24-hour linear smear. The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from RFC 3339 date strings. Corresponds to the JSON property completionTime



651
652
653
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 651

def completion_time
  @completion_time
end

#creation_timeGoogle::Apis::ToolresultsV1beta3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are " smeared" so that no leap second table is needed for interpretation, using a 24-hour linear smear. The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from RFC 3339 date strings. Corresponds to the JSON property creationTime



665
666
667
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 665

def creation_time
  @creation_time
end

#dimension_valueArray<Google::Apis::ToolresultsV1beta3::EnvironmentDimensionValueEntry>

Dimension values describing the environment. Dimension values always consist of "Model", "Version", "Locale", and "Orientation". - In response: always set - In create request: always set - In update request: never set Corresponds to the JSON property dimensionValue



672
673
674
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 672

def dimension_value
  @dimension_value
end

#display_nameString

A short human-readable name to display in the UI. Maximum of 100 characters. For example: Nexus 5, API 27. Corresponds to the JSON property displayName

Returns:

  • (String)


678
679
680
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 678

def display_name
  @display_name
end

#environment_idString

Output only. An Environment id. Corresponds to the JSON property environmentId

Returns:

  • (String)


683
684
685
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 683

def environment_id
  @environment_id
end

#environment_resultGoogle::Apis::ToolresultsV1beta3::MergedResult

Merged test result for environment. If the environment has only one step (no reruns or shards), then the merged result is the same as the step result. If the environment has multiple shards and/or reruns, then the results of shards and reruns that belong to the same environment are merged into one environment result. Corresponds to the JSON property environmentResult



692
693
694
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 692

def environment_result
  @environment_result
end

#execution_idString

Output only. An Execution id. Corresponds to the JSON property executionId

Returns:

  • (String)


697
698
699
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 697

def execution_id
  @execution_id
end

#history_idString

Output only. A History id. Corresponds to the JSON property historyId

Returns:

  • (String)


702
703
704
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 702

def history_id
  @history_id
end

#project_idString

Output only. A Project id. Corresponds to the JSON property projectId

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 707

def project_id
  @project_id
end

#results_storageGoogle::Apis::ToolresultsV1beta3::ResultsStorage

The storage for test results. Corresponds to the JSON property resultsStorage



712
713
714
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 712

def results_storage
  @results_storage
end

#shard_summariesArray<Google::Apis::ToolresultsV1beta3::ShardSummary>

Output only. Summaries of shards. Only one shard will present unless sharding feature is enabled in TestExecutionService. Corresponds to the JSON property shardSummaries



718
719
720
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 718

def shard_summaries
  @shard_summaries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



725
726
727
728
729
730
731
732
733
734
735
736
737
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 725

def update!(**args)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @dimension_value = args[:dimension_value] if args.key?(:dimension_value)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @environment_result = args[:environment_result] if args.key?(:environment_result)
  @execution_id = args[:execution_id] if args.key?(:execution_id)
  @history_id = args[:history_id] if args.key?(:history_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @results_storage = args[:results_storage] if args.key?(:results_storage)
  @shard_summaries = args[:shard_summaries] if args.key?(:shard_summaries)
end