Class: Google::Apis::ToolresultsV1beta3::ListHistoriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::ListHistoriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Response message for HistoryService.List
Instance Attribute Summary collapse
-
#histories ⇒ Array<Google::Apis::ToolresultsV1beta3::History>
Histories.
-
#next_page_token ⇒ String
A continuation token to resume the query at the next item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHistoriesResponse
constructor
A new instance of ListHistoriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHistoriesResponse
Returns a new instance of ListHistoriesResponse.
1566 1567 1568 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#histories ⇒ Array<Google::Apis::ToolresultsV1beta3::History>
Histories.
Corresponds to the JSON property histories
1555 1556 1557 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1555 def histories @histories end |
#next_page_token ⇒ String
A continuation token to resume the query at the next item. Will only be set if
there are more histories to fetch. Tokens are valid for up to one hour from
the time of the first list request. For instance, if you make a list request
at 1PM and use the token from this first request 10 minutes later, the token
from this second response will only be valid for 50 minutes.
Corresponds to the JSON property nextPageToken
1564 1565 1566 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1564 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1571 1572 1573 1574 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1571 def update!(**args) @histories = args[:histories] if args.key?(:histories) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |