Class: Google::Apis::ToolresultsV1beta3::ListStepAccessibilityClustersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

Response message for AccessibilityService.ListStepAccessibilityClusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListStepAccessibilityClustersResponse

Returns a new instance of ListStepAccessibilityClustersResponse.



1662
1663
1664
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clustersArray<Google::Apis::ToolresultsV1beta3::SuggestionClusterProto>

A sequence of accessibility suggestions, grouped into clusters. Within the sequence, clusters that belong to the same SuggestionCategory should be adjacent. Within each category, clusters should be ordered by their SuggestionPriority (ERRORs first). The categories should be ordered by their highest priority cluster. Corresponds to the JSON property clusters



1653
1654
1655
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1653

def clusters
  @clusters
end

#nameString

A full resource name of the step. For example, projects/my-project/histories/ bh.1234567890abcdef/executions/ 1234567890123456789/steps/bs.1234567890abcdef Always presents. Corresponds to the JSON property name

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1660

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1667
1668
1669
1670
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1667

def update!(**args)
  @clusters = args[:clusters] if args.key?(:clusters)
  @name = args[:name] if args.key?(:name)
end