Class: Google::Apis::ToolresultsV1beta3::ListStepsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

Response message for StepService.List.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListStepsResponse

Returns a new instance of ListStepsResponse.



1721
1722
1723
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A continuation token to resume the query at the next item. If set, indicates that there are more steps to read, by calling list again with this value in the page_token field. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1714
1715
1716
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1714

def next_page_token
  @next_page_token
end

#stepsArray<Google::Apis::ToolresultsV1beta3::Step>

Steps. Corresponds to the JSON property steps



1719
1720
1721
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1719

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1726
1727
1728
1729
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1726

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @steps = args[:steps] if args.key?(:steps)
end