Class: Google::Apis::ToolresultsV1beta3::MergedResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

Merged test result for environment. If the environment has only one step (no reruns or shards), then the merged result is the same as the step result. If the environment has multiple shards and/or reruns, then the results of shards and reruns that belong to the same environment are merged into one environment result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MergedResult

Returns a new instance of MergedResult.



1838
1839
1840
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#outcomeGoogle::Apis::ToolresultsV1beta3::Outcome

Interprets a result so that humans and machines can act on it. Corresponds to the JSON property outcome



1819
1820
1821
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1819

def outcome
  @outcome
end

#stateString

State of the resource Corresponds to the JSON property state

Returns:

  • (String)


1824
1825
1826
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1824

def state
  @state
end

#test_suite_overviewsArray<Google::Apis::ToolresultsV1beta3::TestSuiteOverview>

The combined and rolled-up result of each test suite that was run as part of this environment. Combining: When the test cases from a suite are run in different steps (sharding), the results are added back together in one overview. (e.g., if shard1 has 2 failures and shard2 has 1 failure than the overview failure_count = 3). Rollup: When test cases from the same suite are run multiple times (flaky), the results are combined (e.g., if testcase1.run1 fails, testcase1.run2 passes, and both testcase2.run1 and testcase2.run2 fail then the overview flaky_count = 1 and failure_count = 1). Corresponds to the JSON property testSuiteOverviews



1836
1837
1838
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1836

def test_suite_overviews
  @test_suite_overviews
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1843
1844
1845
1846
1847
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1843

def update!(**args)
  @outcome = args[:outcome] if args.key?(:outcome)
  @state = args[:state] if args.key?(:state)
  @test_suite_overviews = args[:test_suite_overviews] if args.key?(:test_suite_overviews)
end