Class: Google::Apis::ToolresultsV1beta3::NonSdkApiUsageViolationReport
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::NonSdkApiUsageViolationReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Contains a summary and examples of non-sdk API usage violations.
Instance Attribute Summary collapse
-
#example_apis ⇒ Array<Google::Apis::ToolresultsV1beta3::NonSdkApi>
Examples of the detected API usages.
-
#min_sdk_version ⇒ Fixnum
Minimum API level required for the application to run.
-
#target_sdk_version ⇒ Fixnum
Specifies the API Level on which the application is designed to run.
-
#unique_apis ⇒ Fixnum
Total number of unique Non-SDK API's accessed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NonSdkApiUsageViolationReport
constructor
A new instance of NonSdkApiUsageViolationReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NonSdkApiUsageViolationReport
Returns a new instance of NonSdkApiUsageViolationReport.
2037 2038 2039 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example_apis ⇒ Array<Google::Apis::ToolresultsV1beta3::NonSdkApi>
Examples of the detected API usages.
Corresponds to the JSON property exampleApis
2020 2021 2022 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2020 def example_apis @example_apis end |
#min_sdk_version ⇒ Fixnum
Minimum API level required for the application to run.
Corresponds to the JSON property minSdkVersion
2025 2026 2027 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2025 def min_sdk_version @min_sdk_version end |
#target_sdk_version ⇒ Fixnum
Specifies the API Level on which the application is designed to run.
Corresponds to the JSON property targetSdkVersion
2030 2031 2032 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2030 def target_sdk_version @target_sdk_version end |
#unique_apis ⇒ Fixnum
Total number of unique Non-SDK API's accessed.
Corresponds to the JSON property uniqueApis
2035 2036 2037 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2035 def unique_apis @unique_apis end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2042 2043 2044 2045 2046 2047 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2042 def update!(**args) @example_apis = args[:example_apis] if args.key?(:example_apis) @min_sdk_version = args[:min_sdk_version] if args.key?(:min_sdk_version) @target_sdk_version = args[:target_sdk_version] if args.key?(:target_sdk_version) @unique_apis = args[:unique_apis] if args.key?(:unique_apis) end |