Class: Google::Apis::ToolresultsV1beta3::OverlappingUiElements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

A warning that Robo encountered a screen that has overlapping clickable elements; this may indicate a potential UI issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OverlappingUiElements

Returns a new instance of OverlappingUiElements.



2095
2096
2097
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_nameArray<String>

Resource names of the overlapping screen elements Corresponds to the JSON property resourceName

Returns:

  • (Array<String>)


2088
2089
2090
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2088

def resource_name
  @resource_name
end

#screen_idString

The screen id of the elements Corresponds to the JSON property screenId

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2093

def screen_id
  @screen_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2100
2101
2102
2103
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2100

def update!(**args)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @screen_id = args[:screen_id] if args.key?(:screen_id)
end