Class: Google::Apis::ToolresultsV1beta3::PerfSample
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::PerfSample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Resource representing a single performance measure or data point
Instance Attribute Summary collapse
-
#sample_time ⇒ Google::Apis::ToolresultsV1beta3::Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#value ⇒ Float
Value observed Corresponds to the JSON property
value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerfSample
constructor
A new instance of PerfSample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerfSample
Returns a new instance of PerfSample.
2250 2251 2252 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sample_time ⇒ Google::Apis::ToolresultsV1beta3::Timestamp
A Timestamp represents a point in time independent of any time zone or local
calendar, encoded as a count of seconds and fractions of seconds at nanosecond
resolution. The count is relative to an epoch at UTC midnight on January 1,
1970, in the proleptic Gregorian calendar which extends the Gregorian calendar
backwards to year one. All minutes are 60 seconds long. Leap seconds are "
smeared" so that no leap second table is needed for interpretation, using a
24-hour linear smear. The range is
from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to
that range, we ensure that we can convert to and from RFC 3339 date strings.
Corresponds to the JSON property sampleTime
2243 2244 2245 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2243 def sample_time @sample_time end |
#value ⇒ Float
Value observed
Corresponds to the JSON property value
2248 2249 2250 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2248 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2255 2256 2257 2258 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2255 def update!(**args) @sample_time = args[:sample_time] if args.key?(:sample_time) @value = args[:value] if args.key?(:value) end |