Class: Google::Apis::ToolresultsV1beta3::PrimaryStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

Stores rollup test status of multiple steps that were run as a group and outcome of each individual step.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrimaryStep

Returns a new instance of PrimaryStep.



2358
2359
2360
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#individual_outcomeArray<Google::Apis::ToolresultsV1beta3::IndividualOutcome>

Step Id and outcome of each individual step. Corresponds to the JSON property individualOutcome



2350
2351
2352
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2350

def individual_outcome
  @individual_outcome
end

#roll_upString

Rollup test status of multiple steps that were run with the same configuration as a group. Corresponds to the JSON property rollUp

Returns:

  • (String)


2356
2357
2358
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2356

def roll_up
  @roll_up
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2363
2364
2365
2366
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2363

def update!(**args)
  @individual_outcome = args[:individual_outcome] if args.key?(:individual_outcome)
  @roll_up = args[:roll_up] if args.key?(:roll_up)
end