Class: Google::Apis::ToolresultsV1beta3::ShardSummary
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::ShardSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Result summary for a shard in an environment.
Instance Attribute Summary collapse
-
#runs ⇒ Array<Google::Apis::ToolresultsV1beta3::StepSummary>
Summaries of the steps belonging to the shard.
-
#shard_result ⇒ Google::Apis::ToolresultsV1beta3::MergedResult
Merged test result for environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShardSummary
constructor
A new instance of ShardSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShardSummary
Returns a new instance of ShardSummary.
2626 2627 2628 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#runs ⇒ Array<Google::Apis::ToolresultsV1beta3::StepSummary>
Summaries of the steps belonging to the shard. With flaky_test_attempts
enabled from TestExecutionService, more than one run (Step) can present. And
the runs will be sorted by multistep_number.
Corresponds to the JSON property runs
2615 2616 2617 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2615 def runs @runs end |
#shard_result ⇒ Google::Apis::ToolresultsV1beta3::MergedResult
Merged test result for environment. If the environment has only one step (no
reruns or shards), then the merged result is the same as the step result. If
the environment has multiple shards and/or reruns, then the results of shards
and reruns that belong to the same environment are merged into one environment
result.
Corresponds to the JSON property shardResult
2624 2625 2626 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2624 def shard_result @shard_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2631 2632 2633 2634 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2631 def update!(**args) @runs = args[:runs] if args.key?(:runs) @shard_result = args[:shard_result] if args.key?(:shard_result) end |