Class: Google::Apis::ToolresultsV1beta3::TestCase
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::TestCase
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Instance Attribute Summary collapse
-
#elapsed_time ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ Google::Apis::ToolresultsV1beta3::Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#skipped_message ⇒ String
Why the test case was skipped.
-
#stack_traces ⇒ Array<Google::Apis::ToolresultsV1beta3::StackTrace>
The stack trace details if the test case failed or encountered an error.
-
#start_time ⇒ Google::Apis::ToolresultsV1beta3::Timestamp
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution.
-
#status ⇒ String
The status of the test case.
-
#test_case_id ⇒ String
A unique identifier within a Step for this Test Case.
-
#test_case_reference ⇒ Google::Apis::ToolresultsV1beta3::TestCaseReference
A reference to a test case.
-
#tool_outputs ⇒ Array<Google::Apis::ToolresultsV1beta3::ToolOutputReference>
References to opaque files of any format output by the tool execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestCase
constructor
A new instance of TestCase.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestCase
Returns a new instance of TestCase.
3257 3258 3259 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#elapsed_time ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a
count of seconds and fractions of seconds at nanosecond resolution. It is
independent of any calendar and concepts like "day" or "month". It is related
to Timestamp in that the difference between two Timestamp values is a Duration
and it can be added or subtracted from a Timestamp. Range is approximately +-
10,000 years.
Corresponds to the JSON property elapsedTime
3192 3193 3194 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3192 def elapsed_time @elapsed_time end |
#end_time ⇒ Google::Apis::ToolresultsV1beta3::Timestamp
A Timestamp represents a point in time independent of any time zone or local
calendar, encoded as a count of seconds and fractions of seconds at nanosecond
resolution. The count is relative to an epoch at UTC midnight on January 1,
1970, in the proleptic Gregorian calendar which extends the Gregorian calendar
backwards to year one. All minutes are 60 seconds long. Leap seconds are "
smeared" so that no leap second table is needed for interpretation, using a
24-hour linear smear. The range is
from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to
that range, we ensure that we can convert to and from RFC 3339 date strings.
Corresponds to the JSON property endTime
3206 3207 3208 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3206 def end_time @end_time end |
#skipped_message ⇒ String
Why the test case was skipped. Present only for skipped test case
Corresponds to the JSON property skippedMessage
3211 3212 3213 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3211 def @skipped_message end |
#stack_traces ⇒ Array<Google::Apis::ToolresultsV1beta3::StackTrace>
The stack trace details if the test case failed or encountered an error. The
maximum size of the stack traces is 100KiB, beyond which the stack track will
be truncated. Zero if the test case passed.
Corresponds to the JSON property stackTraces
3218 3219 3220 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3218 def stack_traces @stack_traces end |
#start_time ⇒ Google::Apis::ToolresultsV1beta3::Timestamp
A Timestamp represents a point in time independent of any time zone or local
calendar, encoded as a count of seconds and fractions of seconds at nanosecond
resolution. The count is relative to an epoch at UTC midnight on January 1,
1970, in the proleptic Gregorian calendar which extends the Gregorian calendar
backwards to year one. All minutes are 60 seconds long. Leap seconds are "
smeared" so that no leap second table is needed for interpretation, using a
24-hour linear smear. The range is
from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to
that range, we ensure that we can convert to and from RFC 3339 date strings.
Corresponds to the JSON property startTime
3232 3233 3234 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3232 def start_time @start_time end |
#status ⇒ String
The status of the test case. Required.
Corresponds to the JSON property status
3237 3238 3239 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3237 def status @status end |
#test_case_id ⇒ String
A unique identifier within a Step for this Test Case.
Corresponds to the JSON property testCaseId
3242 3243 3244 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3242 def test_case_id @test_case_id end |
#test_case_reference ⇒ Google::Apis::ToolresultsV1beta3::TestCaseReference
A reference to a test case. Test case references are canonically ordered
lexicographically by these three factors: * First, by test_suite_name. *
Second, by class_name. * Third, by name.
Corresponds to the JSON property testCaseReference
3249 3250 3251 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3249 def test_case_reference @test_case_reference end |
#tool_outputs ⇒ Array<Google::Apis::ToolresultsV1beta3::ToolOutputReference>
References to opaque files of any format output by the tool execution. @
OutputOnly
Corresponds to the JSON property toolOutputs
3255 3256 3257 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3255 def tool_outputs @tool_outputs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3262 def update!(**args) @elapsed_time = args[:elapsed_time] if args.key?(:elapsed_time) @end_time = args[:end_time] if args.key?(:end_time) @skipped_message = args[:skipped_message] if args.key?(:skipped_message) @stack_traces = args[:stack_traces] if args.key?(:stack_traces) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @test_case_id = args[:test_case_id] if args.key?(:test_case_id) @test_case_reference = args[:test_case_reference] if args.key?(:test_case_reference) @tool_outputs = args[:tool_outputs] if args.key?(:tool_outputs) end |