Class: Google::Apis::ToolresultsV1beta3::TestIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

An issue detected occurring during a test execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestIssue

Returns a new instance of TestIssue.



3414
3415
3416
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Category of issue. Required. Corresponds to the JSON property category

Returns:

  • (String)


3364
3365
3366
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3364

def category
  @category
end

#error_messageString

A brief human-readable message describing the issue. Required. Corresponds to the JSON property errorMessage

Returns:

  • (String)


3369
3370
3371
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3369

def error_message
  @error_message
end

#severityString

Severity of issue. Required. Corresponds to the JSON property severity

Returns:

  • (String)


3374
3375
3376
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3374

def severity
  @severity
end

#stack_traceGoogle::Apis::ToolresultsV1beta3::StackTrace

A stacktrace. Corresponds to the JSON property stackTrace



3379
3380
3381
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3379

def stack_trace
  @stack_trace
end

#typeString

Type of issue. Required. Corresponds to the JSON property type

Returns:

  • (String)


3384
3385
3386
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3384

def type
  @type
end

#warning_migrationGoogle::Apis::ToolresultsV1beta3::Any

Any contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message. Protobuf library provides support to pack/unpack Any values in the form of utility functions or additional generated methods of the Any type. Example 1: Pack and unpack a message in C++. Foo foo = ...; Any any; any.PackFrom(foo); ... if (any. UnpackTo(&foo)) ... Example 2: Pack and unpack a message in Java. Foo foo = ...; Any any = Any.pack(foo); ... if (any.is(Foo.class)) foo = any.unpack( Foo.class); Example 3: Pack and unpack a message in Python. foo = Foo(...) any = Any() any.Pack(foo) ... if any.Is(Foo.DESCRIPTOR): any.Unpack(foo) ... Example 4: Pack and unpack a message in Go foo := &pb.Foo... any, err := ptypes.MarshalAny(foo) ... foo := &pb.Foo`if err := ptypes.UnmarshalAny(any, foo); err != nil ... The pack methods provided by protobuf library will by default use 'type.googleapis.com/full.type.name' as the type URL and the unpack methods only use the fully qualified type name after the last '/' in the type URL, for example "foo.bar.com/x/y.z" will yield type name "y.z". # JSON The JSON representation of anAnyvalue uses the regular representation of the deserialized, embedded message, with an additional field@typewhich contains the type URL. Example: package google.profile; message Person string first_name = 1; string last_name = 2; "@type": "type.googleapis.com/ google.profile.Person", "firstName": , "lastName": If the embedded message type is well-known and has a custom JSON representation, that representation will be embedded adding a fieldvaluewhich holds the custom JSON in addition to the@typefield. Example (for message google.protobuf.Duration): "@type": "type.googleapis.com/google.protobuf.Duration", "value": "1.212s" Corresponds to the JSON propertywarning_migration`



3412
3413
3414
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3412

def warning_migration
  @warning_migration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3419
3420
3421
3422
3423
3424
3425
3426
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3419

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @error_message = args[:error_message] if args.key?(:error_message)
  @severity = args[:severity] if args.key?(:severity)
  @stack_trace = args[:stack_trace] if args.key?(:stack_trace)
  @type = args[:type] if args.key?(:type)
  @warning_migration = args[:warning_migration] if args.key?(:warning_migration)
end