Class: Google::Apis::ToolresultsV1beta3::Timestamp
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::Timestamp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are " smeared" so that no leap second table is needed for interpretation, using a 24-hour linear smear. The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from RFC 3339 date strings.
Instance Attribute Summary collapse
-
#nanos ⇒ Fixnum
Non-negative fractions of a second at nanosecond resolution.
-
#seconds ⇒ Fixnum
Represents seconds of UTC time since Unix epoch 1970-01-01T00:00:00Z.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Timestamp
constructor
A new instance of Timestamp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Timestamp
Returns a new instance of Timestamp.
3583 3584 3585 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#nanos ⇒ Fixnum
Non-negative fractions of a second at nanosecond resolution. Negative second
values with fractions must still have non-negative nanos values that count
forward in time. Must be from 0 to 999,999,999 inclusive.
Corresponds to the JSON property nanos
3575 3576 3577 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3575 def nanos @nanos end |
#seconds ⇒ Fixnum
Represents seconds of UTC time since Unix epoch 1970-01-01T00:00:00Z. Must be
from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59Z inclusive.
Corresponds to the JSON property seconds
3581 3582 3583 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3581 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3588 3589 3590 3591 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3588 def update!(**args) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |