Class: Google::Apis::ToolresultsV1beta3::ToolOutputReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

A reference to a ToolExecution output file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolOutputReference

Returns a new instance of ToolOutputReference.



3714
3715
3716
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3714

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timeGoogle::Apis::ToolresultsV1beta3::Timestamp

A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one. All minutes are 60 seconds long. Leap seconds are " smeared" so that no leap second table is needed for interpretation, using a 24-hour linear smear. The range is from 0001-01-01T00:00:00Z to 9999-12-31T23:59:59.999999999Z. By restricting to that range, we ensure that we can convert to and from RFC 3339 date strings. Corresponds to the JSON property creationTime



3700
3701
3702
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3700

def creation_time
  @creation_time
end

#outputGoogle::Apis::ToolresultsV1beta3::FileReference

A reference to a file. Corresponds to the JSON property output



3705
3706
3707
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3705

def output
  @output
end

#test_caseGoogle::Apis::ToolresultsV1beta3::TestCaseReference

A reference to a test case. Test case references are canonically ordered lexicographically by these three factors: * First, by test_suite_name. * Second, by class_name. * Third, by name. Corresponds to the JSON property testCase



3712
3713
3714
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3712

def test_case
  @test_case
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3719
3720
3721
3722
3723
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3719

def update!(**args)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @output = args[:output] if args.key?(:output)
  @test_case = args[:test_case] if args.key?(:test_case)
end