Class: Google::Apis::ToolresultsV1beta3::Image
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::Image
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
An image, with a link to the main image and a thumbnail.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ToolresultsV1beta3::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#source_image ⇒ Google::Apis::ToolresultsV1beta3::ToolOutputReference
A reference to a ToolExecution output file.
-
#step_id ⇒ String
The step to which the image is attached.
-
#thumbnail ⇒ Google::Apis::ToolresultsV1beta3::Thumbnail
A single thumbnail, with its size and format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Image
constructor
A new instance of Image.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Image
Returns a new instance of Image.
1173 1174 1175 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ToolresultsV1beta3::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1156 1157 1158 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1156 def error @error end |
#source_image ⇒ Google::Apis::ToolresultsV1beta3::ToolOutputReference
A reference to a ToolExecution output file.
Corresponds to the JSON property sourceImage
1161 1162 1163 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1161 def source_image @source_image end |
#step_id ⇒ String
The step to which the image is attached. Always set.
Corresponds to the JSON property stepId
1166 1167 1168 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1166 def step_id @step_id end |
#thumbnail ⇒ Google::Apis::ToolresultsV1beta3::Thumbnail
A single thumbnail, with its size and format.
Corresponds to the JSON property thumbnail
1171 1172 1173 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1171 def thumbnail @thumbnail end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1178 1179 1180 1181 1182 1183 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1178 def update!(**args) @error = args[:error] if args.key?(:error) @source_image = args[:source_image] if args.key?(:source_image) @step_id = args[:step_id] if args.key?(:step_id) @thumbnail = args[:thumbnail] if args.key?(:thumbnail) end |