Class: Google::Apis::ToolresultsV1beta3::IndividualOutcome
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::IndividualOutcome
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Step Id and outcome of each individual step that was run as a group with other steps with the same configuration.
Instance Attribute Summary collapse
-
#multistep_number ⇒ Fixnum
Unique int given to each step.
-
#outcome_summary ⇒ String
Corresponds to the JSON property
outcomeSummary. -
#run_duration ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#step_id ⇒ String
Corresponds to the JSON property
stepId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IndividualOutcome
constructor
A new instance of IndividualOutcome.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IndividualOutcome
Returns a new instance of IndividualOutcome.
1283 1284 1285 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#multistep_number ⇒ Fixnum
Unique int given to each step. Ranges from 0(inclusive) to total number of
steps(exclusive). The primary step is 0.
Corresponds to the JSON property multistepNumber
1261 1262 1263 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1261 def multistep_number @multistep_number end |
#outcome_summary ⇒ String
Corresponds to the JSON property outcomeSummary
1266 1267 1268 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1266 def outcome_summary @outcome_summary end |
#run_duration ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a
count of seconds and fractions of seconds at nanosecond resolution. It is
independent of any calendar and concepts like "day" or "month". It is related
to Timestamp in that the difference between two Timestamp values is a Duration
and it can be added or subtracted from a Timestamp. Range is approximately +-
10,000 years.
Corresponds to the JSON property runDuration
1276 1277 1278 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1276 def run_duration @run_duration end |
#step_id ⇒ String
Corresponds to the JSON property stepId
1281 1282 1283 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1281 def step_id @step_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1288 1289 1290 1291 1292 1293 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1288 def update!(**args) @multistep_number = args[:multistep_number] if args.key?(:multistep_number) @outcome_summary = args[:outcome_summary] if args.key?(:outcome_summary) @run_duration = args[:run_duration] if args.key?(:run_duration) @step_id = args[:step_id] if args.key?(:step_id) end |