Class: Google::Apis::ToolresultsV1beta3::IosTest
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::IosTest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
A iOS mobile test specification
Instance Attribute Summary collapse
-
#ios_app_info ⇒ Google::Apis::ToolresultsV1beta3::IosAppInfo
iOS app information Corresponds to the JSON property
iosAppInfo. -
#ios_robo_test ⇒ Google::Apis::ToolresultsV1beta3::IosRoboTest
A Robo test for an iOS application.
-
#ios_test_loop ⇒ Google::Apis::ToolresultsV1beta3::IosTestLoop
A game loop test of an iOS application.
-
#ios_xc_test ⇒ Google::Apis::ToolresultsV1beta3::IosXcTest
A test of an iOS application that uses the XCTest framework.
-
#test_timeout ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IosTest
constructor
A new instance of IosTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IosTest
Returns a new instance of IosTest.
1394 1395 1396 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ios_app_info ⇒ Google::Apis::ToolresultsV1beta3::IosAppInfo
iOS app information
Corresponds to the JSON property iosAppInfo
1367 1368 1369 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1367 def ios_app_info @ios_app_info end |
#ios_robo_test ⇒ Google::Apis::ToolresultsV1beta3::IosRoboTest
A Robo test for an iOS application.
Corresponds to the JSON property iosRoboTest
1372 1373 1374 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1372 def ios_robo_test @ios_robo_test end |
#ios_test_loop ⇒ Google::Apis::ToolresultsV1beta3::IosTestLoop
A game loop test of an iOS application.
Corresponds to the JSON property iosTestLoop
1377 1378 1379 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1377 def ios_test_loop @ios_test_loop end |
#ios_xc_test ⇒ Google::Apis::ToolresultsV1beta3::IosXcTest
A test of an iOS application that uses the XCTest framework.
Corresponds to the JSON property iosXcTest
1382 1383 1384 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1382 def ios_xc_test @ios_xc_test end |
#test_timeout ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a
count of seconds and fractions of seconds at nanosecond resolution. It is
independent of any calendar and concepts like "day" or "month". It is related
to Timestamp in that the difference between two Timestamp values is a Duration
and it can be added or subtracted from a Timestamp. Range is approximately +-
10,000 years.
Corresponds to the JSON property testTimeout
1392 1393 1394 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1392 def test_timeout @test_timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1399 1400 1401 1402 1403 1404 1405 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1399 def update!(**args) @ios_app_info = args[:ios_app_info] if args.key?(:ios_app_info) @ios_robo_test = args[:ios_robo_test] if args.key?(:ios_robo_test) @ios_test_loop = args[:ios_test_loop] if args.key?(:ios_test_loop) @ios_xc_test = args[:ios_xc_test] if args.key?(:ios_xc_test) @test_timeout = args[:test_timeout] if args.key?(:test_timeout) end |