Class: Google::Apis::ToolresultsV1beta3::ListHistoriesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

Response message for HistoryService.List

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListHistoriesResponse

Returns a new instance of ListHistoriesResponse.



1553
1554
1555
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#historiesArray<Google::Apis::ToolresultsV1beta3::History>

Histories. Corresponds to the JSON property histories



1542
1543
1544
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1542

def histories
  @histories
end

#next_page_tokenString

A continuation token to resume the query at the next item. Will only be set if there are more histories to fetch. Tokens are valid for up to one hour from the time of the first list request. For instance, if you make a list request at 1PM and use the token from this first request 10 minutes later, the token from this second response will only be valid for 50 minutes. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1551
1552
1553
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1551

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1558
1559
1560
1561
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1558

def update!(**args)
  @histories = args[:histories] if args.key?(:histories)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end