Class: Google::Apis::ToolresultsV1beta3::ListPerfSamplesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::ListPerfSamplesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Optional, returned if result size exceeds the page size specified in the request (or the default page size, 500, if unspecified).
-
#perf_samples ⇒ Array<Google::Apis::ToolresultsV1beta3::PerfSample>
Corresponds to the JSON property
perfSamples.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPerfSamplesResponse
constructor
A new instance of ListPerfSamplesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPerfSamplesResponse
Returns a new instance of ListPerfSamplesResponse.
1612 1613 1614 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Optional, returned if result size exceeds the page size specified in the
request (or the default page size, 500, if unspecified). It indicates the last
sample timestamp to be used as page_token in subsequent request
Corresponds to the JSON property nextPageToken
1605 1606 1607 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1605 def next_page_token @next_page_token end |
#perf_samples ⇒ Array<Google::Apis::ToolresultsV1beta3::PerfSample>
Corresponds to the JSON property perfSamples
1610 1611 1612 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1610 def perf_samples @perf_samples end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1617 1618 1619 1620 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1617 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @perf_samples = args[:perf_samples] if args.key?(:perf_samples) end |