Class: Google::Apis::ToolresultsV1beta3::ListPerfSamplesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPerfSamplesResponse

Returns a new instance of ListPerfSamplesResponse.



1599
1600
1601
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Optional, returned if result size exceeds the page size specified in the request (or the default page size, 500, if unspecified). It indicates the last sample timestamp to be used as page_token in subsequent request Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1592
1593
1594
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1592

def next_page_token
  @next_page_token
end

#perf_samplesArray<Google::Apis::ToolresultsV1beta3::PerfSample>

Corresponds to the JSON property perfSamples



1597
1598
1599
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1597

def perf_samples
  @perf_samples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1604
1605
1606
1607
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 1604

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @perf_samples = args[:perf_samples] if args.key?(:perf_samples)
end