Class: Google::Apis::ToolresultsV1beta3::ScreenshotCluster
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::ScreenshotCluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Instance Attribute Summary collapse
-
#activity ⇒ String
A string that describes the activity of every screen in the cluster.
-
#cluster_id ⇒ String
A unique identifier for the cluster.
-
#key_screen ⇒ Google::Apis::ToolresultsV1beta3::Screen
A singular screen that represents the cluster as a whole.
-
#screens ⇒ Array<Google::Apis::ToolresultsV1beta3::Screen>
Full list of screens.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScreenshotCluster
constructor
A new instance of ScreenshotCluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScreenshotCluster
Returns a new instance of ScreenshotCluster.
2593 2594 2595 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activity ⇒ String
A string that describes the activity of every screen in the cluster.
Corresponds to the JSON property activity
2573 2574 2575 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2573 def activity @activity end |
#cluster_id ⇒ String
A unique identifier for the cluster. @OutputOnly
Corresponds to the JSON property clusterId
2578 2579 2580 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2578 def cluster_id @cluster_id end |
#key_screen ⇒ Google::Apis::ToolresultsV1beta3::Screen
A singular screen that represents the cluster as a whole. This screen will act
as the "cover" of the entire cluster. When users look at the clusters, only
the key screen from each cluster will be shown. Which screen is the key screen
is determined by the ClusteringAlgorithm
Corresponds to the JSON property keyScreen
2586 2587 2588 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2586 def key_screen @key_screen end |
#screens ⇒ Array<Google::Apis::ToolresultsV1beta3::Screen>
Full list of screens.
Corresponds to the JSON property screens
2591 2592 2593 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2591 def screens @screens end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2598 2599 2600 2601 2602 2603 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2598 def update!(**args) @activity = args[:activity] if args.key?(:activity) @cluster_id = args[:cluster_id] if args.key?(:cluster_id) @key_screen = args[:key_screen] if args.key?(:key_screen) @screens = args[:screens] if args.key?(:screens) end |