Class: Google::Apis::ToolresultsV1beta3::ShardSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

Result summary for a shard in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShardSummary

Returns a new instance of ShardSummary.



2613
2614
2615
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#runsArray<Google::Apis::ToolresultsV1beta3::StepSummary>

Summaries of the steps belonging to the shard. With flaky_test_attempts enabled from TestExecutionService, more than one run (Step) can present. And the runs will be sorted by multistep_number. Corresponds to the JSON property runs



2602
2603
2604
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2602

def runs
  @runs
end

#shard_resultGoogle::Apis::ToolresultsV1beta3::MergedResult

Merged test result for environment. If the environment has only one step (no reruns or shards), then the merged result is the same as the step result. If the environment has multiple shards and/or reruns, then the results of shards and reruns that belong to the same environment are merged into one environment result. Corresponds to the JSON property shardResult



2611
2612
2613
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2611

def shard_result
  @shard_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2618
2619
2620
2621
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2618

def update!(**args)
  @runs = args[:runs] if args.key?(:runs)
  @shard_result = args[:shard_result] if args.key?(:shard_result)
end