Class: Google::Apis::ToolresultsV1beta3::SkippedDetail
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::SkippedDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Details for an outcome with a SKIPPED outcome summary.
Instance Attribute Summary collapse
-
#incompatible_app_version ⇒ Boolean
(also: #incompatible_app_version?)
If the App doesn't support the specific API level.
-
#incompatible_architecture ⇒ Boolean
(also: #incompatible_architecture?)
If the App doesn't run on the specific architecture, for example, x86.
-
#incompatible_device ⇒ Boolean
(also: #incompatible_device?)
If the requested OS version doesn't run on the specific device model.
-
#pending_timeout ⇒ Boolean
(also: #pending_timeout?)
Indicates that the test could not be scheduled in the requested time because no suitable device was available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SkippedDetail
constructor
A new instance of SkippedDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SkippedDetail
Returns a new instance of SkippedDetail.
2653 2654 2655 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#incompatible_app_version ⇒ Boolean Also known as: incompatible_app_version?
If the App doesn't support the specific API level.
Corresponds to the JSON property incompatibleAppVersion
2631 2632 2633 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2631 def incompatible_app_version @incompatible_app_version end |
#incompatible_architecture ⇒ Boolean Also known as: incompatible_architecture?
If the App doesn't run on the specific architecture, for example, x86.
Corresponds to the JSON property incompatibleArchitecture
2637 2638 2639 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2637 def incompatible_architecture @incompatible_architecture end |
#incompatible_device ⇒ Boolean Also known as: incompatible_device?
If the requested OS version doesn't run on the specific device model.
Corresponds to the JSON property incompatibleDevice
2643 2644 2645 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2643 def incompatible_device @incompatible_device end |
#pending_timeout ⇒ Boolean Also known as: pending_timeout?
Indicates that the test could not be scheduled in the requested time because
no suitable device was available.
Corresponds to the JSON property pendingTimeout
2650 2651 2652 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2650 def pending_timeout @pending_timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2658 2659 2660 2661 2662 2663 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 2658 def update!(**args) @incompatible_app_version = args[:incompatible_app_version] if args.key?(:incompatible_app_version) @incompatible_architecture = args[:incompatible_architecture] if args.key?(:incompatible_architecture) @incompatible_device = args[:incompatible_device] if args.key?(:incompatible_device) @pending_timeout = args[:pending_timeout] if args.key?(:pending_timeout) end |