Class: Google::Apis::ToolresultsV1beta3::SuggestionClusterProto
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::SuggestionClusterProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
A set of similar suggestions that we suspect are closely related. This proto and most of the nested protos are branched from foxandcrown.prelaunchreport. service.SuggestionClusterProto, replacing PLR's dependencies with FTL's.
Instance Attribute Summary collapse
-
#category ⇒ String
Category in which these types of suggestions should appear.
-
#suggestions ⇒ Array<Google::Apis::ToolresultsV1beta3::SuggestionProto>
A sequence of suggestions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuggestionClusterProto
constructor
A new instance of SuggestionClusterProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuggestionClusterProto
Returns a new instance of SuggestionClusterProto.
3076 3077 3078 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
Category in which these types of suggestions should appear. Always set.
Corresponds to the JSON property category
3067 3068 3069 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3067 def category @category end |
#suggestions ⇒ Array<Google::Apis::ToolresultsV1beta3::SuggestionProto>
A sequence of suggestions. All of the suggestions within a cluster must have
the same SuggestionPriority and belong to the same SuggestionCategory.
Suggestions with the same screenshot URL should be adjacent.
Corresponds to the JSON property suggestions
3074 3075 3076 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3074 def suggestions @suggestions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3081 3082 3083 3084 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3081 def update!(**args) @category = args[:category] if args.key?(:category) @suggestions = args[:suggestions] if args.key?(:suggestions) end |