Class: Google::Apis::ToolresultsV1beta3::SuggestionProto
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::SuggestionProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Instance Attribute Summary collapse
-
#help_url ⇒ String
Reference to a help center article concerning this type of suggestion.
-
#long_message ⇒ Google::Apis::ToolresultsV1beta3::SafeHtmlProto
IMPORTANT: It is unsafe to accept this message from an untrusted source, since it's trivial for an attacker to forge serialized messages that don't fulfill the type's safety contract -- for example, it could contain attacker controlled script.
-
#priority ⇒ String
Relative importance of a suggestion.
-
#pseudo_resource_id ⇒ String
A somewhat human readable identifier of the source view, if it does not have a resource_name.
-
#region ⇒ Google::Apis::ToolresultsV1beta3::RegionProto
A rectangular region.
-
#resource_name ⇒ String
Reference to a view element, identified by its resource name, if it has one.
-
#screen_id ⇒ String
ID of the screen for the suggestion.
-
#secondary_priority ⇒ Float
Relative importance of a suggestion as compared with other suggestions that have the same priority and category.
-
#short_message ⇒ Google::Apis::ToolresultsV1beta3::SafeHtmlProto
IMPORTANT: It is unsafe to accept this message from an untrusted source, since it's trivial for an attacker to forge serialized messages that don't fulfill the type's safety contract -- for example, it could contain attacker controlled script.
-
#title ⇒ String
General title for the suggestion, in the user's language, without markup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuggestionProto
constructor
A new instance of SuggestionProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuggestionProto
Returns a new instance of SuggestionProto.
3161 3162 3163 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#help_url ⇒ String
Reference to a help center article concerning this type of suggestion. Always
set.
Corresponds to the JSON property helpUrl
3095 3096 3097 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3095 def help_url @help_url end |
#long_message ⇒ Google::Apis::ToolresultsV1beta3::SafeHtmlProto
IMPORTANT: It is unsafe to accept this message from an untrusted source, since
it's trivial for an attacker to forge serialized messages that don't fulfill
the type's safety contract -- for example, it could contain attacker
controlled script. A system which receives a SafeHtmlProto implicitly trusts
the producer of the SafeHtmlProto. So, it's generally safe to return this
message in RPC responses, but generally unsafe to accept it in RPC requests.
Corresponds to the JSON property longMessage
3105 3106 3107 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3105 def @long_message end |
#priority ⇒ String
Relative importance of a suggestion. Always set.
Corresponds to the JSON property priority
3110 3111 3112 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3110 def priority @priority end |
#pseudo_resource_id ⇒ String
A somewhat human readable identifier of the source view, if it does not have a
resource_name. This is a path within the accessibility hierarchy, an element
with resource name; similar to an XPath.
Corresponds to the JSON property pseudoResourceId
3117 3118 3119 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3117 def pseudo_resource_id @pseudo_resource_id end |
#region ⇒ Google::Apis::ToolresultsV1beta3::RegionProto
A rectangular region.
Corresponds to the JSON property region
3122 3123 3124 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3122 def region @region end |
#resource_name ⇒ String
Reference to a view element, identified by its resource name, if it has one.
Corresponds to the JSON property resourceName
3127 3128 3129 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3127 def resource_name @resource_name end |
#screen_id ⇒ String
ID of the screen for the suggestion. It is used for getting the corresponding
screenshot path. For example, screen_id "1" corresponds to "1.png" file in GCS.
Always set.
Corresponds to the JSON property screenId
3134 3135 3136 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3134 def screen_id @screen_id end |
#secondary_priority ⇒ Float
Relative importance of a suggestion as compared with other suggestions that
have the same priority and category. This is a meaningless value that can be
used to order suggestions that are in the same category and have the same
priority. The larger values have higher priority (i.e., are more important).
Optional.
Corresponds to the JSON property secondaryPriority
3143 3144 3145 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3143 def secondary_priority @secondary_priority end |
#short_message ⇒ Google::Apis::ToolresultsV1beta3::SafeHtmlProto
IMPORTANT: It is unsafe to accept this message from an untrusted source, since
it's trivial for an attacker to forge serialized messages that don't fulfill
the type's safety contract -- for example, it could contain attacker
controlled script. A system which receives a SafeHtmlProto implicitly trusts
the producer of the SafeHtmlProto. So, it's generally safe to return this
message in RPC responses, but generally unsafe to accept it in RPC requests.
Corresponds to the JSON property shortMessage
3153 3154 3155 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3153 def @short_message end |
#title ⇒ String
General title for the suggestion, in the user's language, without markup.
Always set.
Corresponds to the JSON property title
3159 3160 3161 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3159 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3166 3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3166 def update!(**args) @help_url = args[:help_url] if args.key?(:help_url) @long_message = args[:long_message] if args.key?(:long_message) @priority = args[:priority] if args.key?(:priority) @pseudo_resource_id = args[:pseudo_resource_id] if args.key?(:pseudo_resource_id) @region = args[:region] if args.key?(:region) @resource_name = args[:resource_name] if args.key?(:resource_name) @screen_id = args[:screen_id] if args.key?(:screen_id) @secondary_priority = args[:secondary_priority] if args.key?(:secondary_priority) @short_message = args[:short_message] if args.key?(:short_message) @title = args[:title] if args.key?(:title) end |