Class: Google::Apis::ToolresultsV1beta3::SuggestionProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuggestionProto

Returns a new instance of SuggestionProto.



3148
3149
3150
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#help_urlString

Reference to a help center article concerning this type of suggestion. Always set. Corresponds to the JSON property helpUrl

Returns:

  • (String)


3082
3083
3084
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3082

def help_url
  @help_url
end

#long_messageGoogle::Apis::ToolresultsV1beta3::SafeHtmlProto

IMPORTANT: It is unsafe to accept this message from an untrusted source, since it's trivial for an attacker to forge serialized messages that don't fulfill the type's safety contract -- for example, it could contain attacker controlled script. A system which receives a SafeHtmlProto implicitly trusts the producer of the SafeHtmlProto. So, it's generally safe to return this message in RPC responses, but generally unsafe to accept it in RPC requests. Corresponds to the JSON property longMessage



3092
3093
3094
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3092

def long_message
  @long_message
end

#priorityString

Relative importance of a suggestion. Always set. Corresponds to the JSON property priority

Returns:

  • (String)


3097
3098
3099
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3097

def priority
  @priority
end

#pseudo_resource_idString

A somewhat human readable identifier of the source view, if it does not have a resource_name. This is a path within the accessibility hierarchy, an element with resource name; similar to an XPath. Corresponds to the JSON property pseudoResourceId

Returns:

  • (String)


3104
3105
3106
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3104

def pseudo_resource_id
  @pseudo_resource_id
end

#regionGoogle::Apis::ToolresultsV1beta3::RegionProto

A rectangular region. Corresponds to the JSON property region



3109
3110
3111
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3109

def region
  @region
end

#resource_nameString

Reference to a view element, identified by its resource name, if it has one. Corresponds to the JSON property resourceName

Returns:

  • (String)


3114
3115
3116
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3114

def resource_name
  @resource_name
end

#screen_idString

ID of the screen for the suggestion. It is used for getting the corresponding screenshot path. For example, screen_id "1" corresponds to "1.png" file in GCS. Always set. Corresponds to the JSON property screenId

Returns:

  • (String)


3121
3122
3123
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3121

def screen_id
  @screen_id
end

#secondary_priorityFloat

Relative importance of a suggestion as compared with other suggestions that have the same priority and category. This is a meaningless value that can be used to order suggestions that are in the same category and have the same priority. The larger values have higher priority (i.e., are more important). Optional. Corresponds to the JSON property secondaryPriority

Returns:

  • (Float)


3130
3131
3132
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3130

def secondary_priority
  @secondary_priority
end

#short_messageGoogle::Apis::ToolresultsV1beta3::SafeHtmlProto

IMPORTANT: It is unsafe to accept this message from an untrusted source, since it's trivial for an attacker to forge serialized messages that don't fulfill the type's safety contract -- for example, it could contain attacker controlled script. A system which receives a SafeHtmlProto implicitly trusts the producer of the SafeHtmlProto. So, it's generally safe to return this message in RPC responses, but generally unsafe to accept it in RPC requests. Corresponds to the JSON property shortMessage



3140
3141
3142
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3140

def short_message
  @short_message
end

#titleString

General title for the suggestion, in the user's language, without markup. Always set. Corresponds to the JSON property title

Returns:

  • (String)


3146
3147
3148
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3146

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3153
3154
3155
3156
3157
3158
3159
3160
3161
3162
3163
3164
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3153

def update!(**args)
  @help_url = args[:help_url] if args.key?(:help_url)
  @long_message = args[:long_message] if args.key?(:long_message)
  @priority = args[:priority] if args.key?(:priority)
  @pseudo_resource_id = args[:pseudo_resource_id] if args.key?(:pseudo_resource_id)
  @region = args[:region] if args.key?(:region)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @screen_id = args[:screen_id] if args.key?(:screen_id)
  @secondary_priority = args[:secondary_priority] if args.key?(:secondary_priority)
  @short_message = args[:short_message] if args.key?(:short_message)
  @title = args[:title] if args.key?(:title)
end