Class: Google::Apis::ToolresultsV1beta3::TestExecutionStep

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

A step that represents running tests. It accepts ant-junit xml files which will be parsed into structured test results by the service. Xml file paths are updated in order to append more files, however they can't be deleted. Users can also add test results manually by using the test_result field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestExecutionStep

Returns a new instance of TestExecutionStep.



3331
3332
3333
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#test_issuesArray<Google::Apis::ToolresultsV1beta3::TestIssue>

Issues observed during the test execution. For example, if the mobile app under test crashed during the test, the error message and the stack trace content can be recorded here to assist debugging. - In response: present if set by create or update - In create/update request: optional Corresponds to the JSON property testIssues



3308
3309
3310
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3308

def test_issues
  @test_issues
end

#test_suite_overviewsArray<Google::Apis::ToolresultsV1beta3::TestSuiteOverview>

List of test suite overview contents. This could be parsed from xUnit XML log by server, or uploaded directly by user. This references should only be called when test suites are fully parsed or uploaded. The maximum allowed number of test suite overviews per step is 1000. - In response: always set - In create request: optional - In update request: never (use publishXunitXmlFiles custom method instead) Corresponds to the JSON property testSuiteOverviews



3318
3319
3320
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3318

def test_suite_overviews
  @test_suite_overviews
end

#test_timingGoogle::Apis::ToolresultsV1beta3::TestTiming

Testing timing break down to know phases. Corresponds to the JSON property testTiming



3323
3324
3325
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3323

def test_timing
  @test_timing
end

#tool_executionGoogle::Apis::ToolresultsV1beta3::ToolExecution

An execution of an arbitrary tool. It could be a test runner or a tool copying artifacts or deploying code. Corresponds to the JSON property toolExecution



3329
3330
3331
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3329

def tool_execution
  @tool_execution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3336
3337
3338
3339
3340
3341
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3336

def update!(**args)
  @test_issues = args[:test_issues] if args.key?(:test_issues)
  @test_suite_overviews = args[:test_suite_overviews] if args.key?(:test_suite_overviews)
  @test_timing = args[:test_timing] if args.key?(:test_timing)
  @tool_execution = args[:tool_execution] if args.key?(:tool_execution)
end