Class: Google::Apis::ToolresultsV1beta3::TestIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

An issue detected occurring during a test execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestIssue

Returns a new instance of TestIssue.



3401
3402
3403
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Category of issue. Required. Corresponds to the JSON property category

Returns:

  • (String)


3351
3352
3353
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3351

def category
  @category
end

#error_messageString

A brief human-readable message describing the issue. Required. Corresponds to the JSON property errorMessage

Returns:

  • (String)


3356
3357
3358
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3356

def error_message
  @error_message
end

#severityString

Severity of issue. Required. Corresponds to the JSON property severity

Returns:

  • (String)


3361
3362
3363
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3361

def severity
  @severity
end

#stack_traceGoogle::Apis::ToolresultsV1beta3::StackTrace

A stacktrace. Corresponds to the JSON property stackTrace



3366
3367
3368
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3366

def stack_trace
  @stack_trace
end

#typeString

Type of issue. Required. Corresponds to the JSON property type

Returns:

  • (String)


3371
3372
3373
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3371

def type
  @type
end

#warning_migrationGoogle::Apis::ToolresultsV1beta3::Any

Any contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message. Protobuf library provides support to pack/unpack Any values in the form of utility functions or additional generated methods of the Any type. Example 1: Pack and unpack a message in C++. Foo foo = ...; Any any; any.PackFrom(foo); ... if (any. UnpackTo(&foo)) ... Example 2: Pack and unpack a message in Java. Foo foo = ...; Any any = Any.pack(foo); ... if (any.is(Foo.class)) foo = any.unpack( Foo.class); Example 3: Pack and unpack a message in Python. foo = Foo(...) any = Any() any.Pack(foo) ... if any.Is(Foo.DESCRIPTOR): any.Unpack(foo) ... Example 4: Pack and unpack a message in Go foo := &pb.Foo... any, err := ptypes.MarshalAny(foo) ... foo := &pb.Foo`if err := ptypes.UnmarshalAny(any, foo); err != nil ... The pack methods provided by protobuf library will by default use 'type.googleapis.com/full.type.name' as the type URL and the unpack methods only use the fully qualified type name after the last '/' in the type URL, for example "foo.bar.com/x/y.z" will yield type name "y.z". # JSON The JSON representation of anAnyvalue uses the regular representation of the deserialized, embedded message, with an additional field@typewhich contains the type URL. Example: package google.profile; message Person string first_name = 1; string last_name = 2; "@type": "type.googleapis.com/ google.profile.Person", "firstName": , "lastName": If the embedded message type is well-known and has a custom JSON representation, that representation will be embedded adding a fieldvaluewhich holds the custom JSON in addition to the@typefield. Example (for message google.protobuf.Duration): "@type": "type.googleapis.com/google.protobuf.Duration", "value": "1.212s" Corresponds to the JSON propertywarning_migration`



3399
3400
3401
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3399

def warning_migration
  @warning_migration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3406
3407
3408
3409
3410
3411
3412
3413
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3406

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @error_message = args[:error_message] if args.key?(:error_message)
  @severity = args[:severity] if args.key?(:severity)
  @stack_trace = args[:stack_trace] if args.key?(:stack_trace)
  @type = args[:type] if args.key?(:type)
  @warning_migration = args[:warning_migration] if args.key?(:warning_migration)
end