Class: Google::Apis::ToolresultsV1beta3::TestSuiteOverview

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb

Overview

A summary of a test suite result either parsed from XML or uploaded directly by a user. Note: the API related comments are for StepService only. This message is also being used in ExecutionService in a read only mode for the corresponding step.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestSuiteOverview

Returns a new instance of TestSuiteOverview.



3476
3477
3478
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#elapsed_timeGoogle::Apis::ToolresultsV1beta3::Duration

A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". It is related to Timestamp in that the difference between two Timestamp values is a Duration and it can be added or subtracted from a Timestamp. Range is approximately +- 10,000 years. Corresponds to the JSON property elapsedTime



3431
3432
3433
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3431

def elapsed_time
  @elapsed_time
end

#error_countFixnum

Number of test cases in error, typically set by the service by parsing the xml_source. - In create/response: always set - In update request: never Corresponds to the JSON property errorCount

Returns:

  • (Fixnum)


3437
3438
3439
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3437

def error_count
  @error_count
end

#failure_countFixnum

Number of failed test cases, typically set by the service by parsing the xml_source. May also be set by the user. - In create/response: always set - In update request: never Corresponds to the JSON property failureCount

Returns:

  • (Fixnum)


3444
3445
3446
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3444

def failure_count
  @failure_count
end

#flaky_countFixnum

Number of flaky test cases, set by the service by rolling up flaky test attempts. Present only for rollup test suite overview at environment level. A step cannot have flaky test cases. Corresponds to the JSON property flakyCount

Returns:

  • (Fixnum)


3451
3452
3453
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3451

def flaky_count
  @flaky_count
end

#nameString

The name of the test suite. - In create/response: always set - In update request: never Corresponds to the JSON property name

Returns:

  • (String)


3457
3458
3459
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3457

def name
  @name
end

#skipped_countFixnum

Number of test cases not run, typically set by the service by parsing the xml_source. - In create/response: always set - In update request: never Corresponds to the JSON property skippedCount

Returns:

  • (Fixnum)


3463
3464
3465
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3463

def skipped_count
  @skipped_count
end

#total_countFixnum

Number of test cases, typically set by the service by parsing the xml_source. - In create/response: always set - In update request: never Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


3469
3470
3471
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3469

def total_count
  @total_count
end

#xml_sourceGoogle::Apis::ToolresultsV1beta3::FileReference

A reference to a file. Corresponds to the JSON property xmlSource



3474
3475
3476
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3474

def xml_source
  @xml_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3481

def update!(**args)
  @elapsed_time = args[:elapsed_time] if args.key?(:elapsed_time)
  @error_count = args[:error_count] if args.key?(:error_count)
  @failure_count = args[:failure_count] if args.key?(:failure_count)
  @flaky_count = args[:flaky_count] if args.key?(:flaky_count)
  @name = args[:name] if args.key?(:name)
  @skipped_count = args[:skipped_count] if args.key?(:skipped_count)
  @total_count = args[:total_count] if args.key?(:total_count)
  @xml_source = args[:xml_source] if args.key?(:xml_source)
end