Class: Google::Apis::ToolresultsV1beta3::TestTiming
- Inherits:
-
Object
- Object
- Google::Apis::ToolresultsV1beta3::TestTiming
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/toolresults_v1beta3/classes.rb,
lib/google/apis/toolresults_v1beta3/representations.rb,
lib/google/apis/toolresults_v1beta3/representations.rb
Overview
Testing timing break down to know phases.
Instance Attribute Summary collapse
-
#test_process_duration ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestTiming
constructor
A new instance of TestTiming.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestTiming
Returns a new instance of TestTiming.
3507 3508 3509 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#test_process_duration ⇒ Google::Apis::ToolresultsV1beta3::Duration
A Duration represents a signed, fixed-length span of time represented as a
count of seconds and fractions of seconds at nanosecond resolution. It is
independent of any calendar and concepts like "day" or "month". It is related
to Timestamp in that the difference between two Timestamp values is a Duration
and it can be added or subtracted from a Timestamp. Range is approximately +-
10,000 years.
Corresponds to the JSON property testProcessDuration
3505 3506 3507 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3505 def test_process_duration @test_process_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3512 3513 3514 |
# File 'lib/google/apis/toolresults_v1beta3/classes.rb', line 3512 def update!(**args) @test_process_duration = args[:test_process_duration] if args.key?(:test_process_duration) end |